import path from "node:path";
export const scripts = (answers) => {
  return {
    start:
      answers.language === "JavaScript"
        ? "node dist/index.js"
        : "ts-node-dev --respawn dist/index.ts",
    "dev:watch":
      answers.language === "JavaScript" ? "nodemon dist/index.js" : "tsc",
    build:
      answers.language === "JavaScript"
        ? "esbuild dist/index.js --bundle --outfile=dist/index.js"
        : "tsc",
  };
};
export const questions = [
  {
    type: "input",
    name: "projectName",
    message: "Enter your project name:",
    default: "buildmatix-project",
  },
  {
    type: "list",
    name: "language",
    message: "Select the project language:",
    choices: ["JavaScript", "TypeScript"],
  },
  {
    type: "list",
    name: "moduleType",
    message: "Select the module type:",
    choices: ["CommonJS", "ES Modules"],
  },
  {
    type: "confirm",
    name: "cors",
    message: "Do you want to use CORS?",
  },
  {
    type: "list",
    name: "installDir",
    message: "Where do you want to install the project?",
    choices: ["Current Directory", "Server Directory"],
  },
];

export function paths(
  targetPath,
  language,
  __dirname,
  installDir,
  answersCheck
) {
  const { isJavaScript, isModule, isCors, indexFileDefault } = answersCheck;
  const basePath =
    installDir === "Server Directory"
      ? path.join(targetPath, "server")
      : targetPath;
  const templatePath = path.join(
    __dirname,
    "..",
    "template",
    language.toLowerCase()
  );
  const indexFilePath = path.join(
    basePath,
    "src",
    language === "TypeScript" ? "index.ts" : "index.js"
  );
  const tsconfigPath = path.join(basePath, "tsconfig.json");
  const packageJsonPath = path.join(basePath, "package.json");
  const eslintConfigPath = path.join(
    basePath,
    isJavaScript ? "eslint.config.js" : "eslint.config.ts"
  );
  const dotenvFilePath = path.join(basePath, ".env");
  const distPath = path.join(basePath, "dist");
  const eslintScripts = path.join(
    __dirname,
    "..",
    "template",
    "scripts",
    "eslint"
  );
  const eslintFileCopyPath = isJavaScript
    ? isModule
      ? path.join(eslintScripts, "eslint-mjs.js")
      : path.join(eslintScripts, "eslint-cjs.js")
    : isModule
    ? path.join(eslintScripts, "eslint-cts.ts")
    : path.join(eslintScripts, "eslint-cts.ts");
  const sourceScripts = path.join(
    __dirname,
    "..",
    "template",
    "scripts",
    isJavaScript ? "javascript" : "typescript"
  );
  const sourceFilePath = !indexFileDefault
    ? isCors
      ? !isJavaScript
        ? isModule
          ? path.join(sourceScripts, "index-mts-cors.ts")
          : path.join(sourceScripts, "index-cts-cors.ts")
        : isModule
        ? path.join(sourceScripts, "index-mjs-cors.js")
        : path.join("", "index-cjs-cors.js")
      : !isJavaScript
      ? path.join(sourceScripts, "index-cts-nocors.ts")
      : path.join(sourceScripts, "index-mjs-nocors.js")
    : null;
  return {
    sourceFilePath,
    basePath,
    templatePath,
    indexFilePath,
    tsconfigPath,
    packageJsonPath,
    eslintConfigPath,
    dotenvFilePath,
    distPath,
    eslintFileCopyPath,
  };
}

export function answersCheck(answers) {
  const isServerDir = answers.installDir === "Server Directory";
  const isJavaScript = answers.language === "JavaScript";
  const isModule = answers.moduleType === "ES Modules";
  const isCors = answers.cors;
  const indexFileDefault =
    (answers.moduleType === "CommonJS" &&
      answers.language === "JavaScript" &&
      answers.cors === "No") ||
    (answers.moduleType === "ES Modules" &&
      answers.language === "TypeScript" &&
      answers.cors === "No");
  return {
    isServerDir,
    isJavaScript,
    isModule,
    isCors,
    indexFileDefault,
  };
}
